#
# This script is a part of Genome Search Toolkit
# Copyright (c) 2014 Kirill Kryukov
# see LICENSE.txt for details.
#

package gst_html;

use strict;
use File::Glob ':glob';
use File::Slurp;

BEGIN
{
    use Exporter();
    our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
    $VERSION = 0.40;
    @ISA = qw(Exporter);
    @EXPORT = qw(
        $page_title
        $project_title

        %html_fragments

        &html_load_fragments
        &process_template
    );
    %EXPORT_TAGS = ();
    @EXPORT_OK = ();
}

our $page_title = '';
our $project_title = '';
our $project_homepage = '';

our %html_fragments = ();

sub html_load_fragments()
{
    foreach my $path (bsd_glob('html/*.html'))
    {
        $path =~ /[\/\\]([^\/\\]+)\.html$/ or die "Can't parse html path \"$path\"\n";
        my $name = $1;
        my $text = read_file($path);
        $html_fragments{$name} = $text;
    }
    foreach my $path (bsd_glob('html/*.css'))
    {
        $path =~ /[\/\\]([^\/\\]+\.css)$/ or die "Can't parse html path \"$path\"\n";
        my $name = $1;
        my $text = read_file($path);
        $html_fragments{$name} = $text;
    }
    $html_fragments{'page_title'} = $page_title;
    $html_fragments{'project_title'} = $page_title;
}

sub process_template($)
{
    my ($html,$name) = @_;

    while ($html =~ /({HTML\s+([^}]+)})/)
    {
        my ($tag,$file) = ($1,$2);
        if (exists($html_fragments{$file}))
        {
            my $replacement = $html_fragments{$file};
            $html =~ s/$tag/$replacement/;
        }
        else
        {
            $html =~ s/$tag//;
        }
    }

    #if ($name ne 'index')
    #{
    #    #print "Processing $name => making title into link\n";
    #    my $a = '<h1>' . $page_title . '</h1>';
    #    #my $b = '<h1><a href="' . $options{'project_homepage'} . '">' . $options{'project_title'} . '</a></h1>';
    #    #$html =~ s/$a/$b/g;
    #}

    return $html;
}

sub error()
{

}

return 1;

END {}
